import json
import logging

SSH_PORT = '22'
HTTP_PORT = '80'
HTTPS_PORT = '443'

def import_dep_info(file_path: str, endpoint_keys: str) -> dict:
    with open(file_path) as f:
        data = json.load(f)    
    
    endpoints = {}
    for key,value in data['outputs'].items():
        if "_ip" in key:
            if isinstance(value, str):
                logging.info(f"Endpoint: {value}:{SSH_PORT}")
                endpoints[value] = {SSH_PORT}
    
    if endpoint_keys != "None":
        list_endpoints = endpoint_keys.split(',')
        for key in data['outputs'].keys():
            if key in list_endpoints:
                endpoint = str(data['outputs'][key])
                prefix,url = endpoint.split("://")
                if ":" in url:
                    host,port = url.split(":")
                else:
                    host = url
                    if prefix == "https":
                        port = HTTPS_PORT
                    elif prefix == 'http':
                        port = HTTP_PORT
                    else:
                        raise Exception(f"Impossible to parse the endpoint port. Endpoint: {endpoint}")
                logging.info(f"Endpoint: {host}:{port}")
                if host not in endpoints:
                    endpoints[host] = {port}
                else:
                    endpoints[host].add(port)
    
    for host,ports in endpoints.items():
        endpoints[host] = sorted(list(ports))
    return endpoints

def process_global_reports_info(reports: dict) -> dict:
    glob_severity = -1
    glob_threat = 'Log'
    for host in reports:
        host_glob_severity = reports[host]['global']['severity']
        if host_glob_severity > glob_severity:
            glob_severity = host_glob_severity
            glob_threat = reports[host]['global']['threat']
    reports['deployment'] = {'severity': glob_severity, 
                            'threat': glob_threat}
    if reports['deployment']['severity'] < 4:
        reports['global'] = "OK"
    else:
        reports['global'] = "NOK"
    return reports